@@ -1,17 +1,19 @@
 from gantry.dataset.main import (
+    _init,
     create_dataset,
     delete_dataset,
     get_dataset,
-    init,
     list_dataset_versions,
     list_datasets,
+    set_working_directory,
 )
 
 __all__ = [
-    "init",
+    "_init",
     "create_dataset",
     "get_dataset",
     "list_dataset_versions",
     "list_datasets",
     "delete_dataset",
+    "set_working_directory",
 ]
