@@ -1,5 +1,5 @@
 import logging
-import pathlib
+from pathlib import Path, PurePath
 from typing import Any, Dict, List, Optional
 
 from typeguard import typechecked
@@ -15,24 +15,46 @@ class GantryDatasetClient:
     def __init__(
         self,
         api_client: APIClient,
-        email: str,
-        bucket_name: Optional[str] = None,
-        aws_region: Optional[str] = None,
-        working_directory: str = str(pathlib.Path().absolute()),
+        working_directory: str = str(Path().absolute()),
     ):
         self._api_client = api_client
-        self.email = email
-        self.bucket_name = bucket_name
-        self.aws_region = aws_region
-        self.workspace = working_directory
+        self._workspace = working_directory
+
+    @property
+    def working_directory(self) -> str:
+        return self._workspace  # type: ignore
+
+    @working_directory.setter
+    def working_directory(self, value: str):
+        if not PurePath(value).is_absolute():
+            logger.warning(
+                f"{value} is not an absolute path, will use {Path(value).resolve()} instead."
+            )
+        else:
+            logger.info(f"Set dataset working directory to {value}")
+        self._workspace = str(Path(value).resolve())
+        Path(self._workspace).mkdir(exist_ok=True)
+
+    def set_working_directory(self, working_dir: str):
+        """
+        Set dataset client working directory. Your dataset will be pulled into this folder.
+
+        Args:
+            working_dir (str): absoluate path of the working directory
+        """
+        self.working_directory = working_dir
 
     @typechecked
-    def create_dataset(self, name: str, model_name: Optional[str] = None) -> GantryDataset:
+    def create_dataset(
+        self, name: str, bucket_name: Optional[str] = None, model_name: Optional[str] = None
+    ) -> GantryDataset:
         """
         Create dataset
 
         Args:
             name (str): dataset name
+            bucket_name (str): Provide bucket name if you want to use your own bucket. If not
+                provided we will use a gantry managed bucket.
             model_name (Optional[str], optional): gantry application name which will be used to set
                 dataset schema if provided.
 
@@ -41,7 +63,6 @@ class GantryDatasetClient:
         """
         data = {
             "name": name,
-            "email": self.email,
         }
 
         if model_name:
@@ -50,30 +71,23 @@ class GantryDatasetClient:
             )
             data["model_id"] = res["data"]["id"]
 
-        if self.bucket_name and self.aws_region:
+        if bucket_name:
             data.update(
                 {
-                    "bucket_name": self.bucket_name,
-                    "aws_region": self.aws_region,
+                    "bucket_name": bucket_name,
                 }
             )
-        elif not (not self.bucket_name and not self.aws_region):
-            raise NotImplementedError(
-                "Both bucket name and region need to be set if you want\
-                 to use your own bucket."
-            )
 
         res = self._api_client.request("POST", "/api/v1/datasets", json=data, raise_for_status=True)
 
         return GantryDataset(
             api_client=self._api_client,
-            user_email=self.email,
             dataset_name=res["data"]["name"],
             dataset_id=res["data"]["id"],
             bucket_name=res["data"]["bucket_name"],
             aws_region=res["data"]["aws_region"],
             dataset_s3_prefix=f"{res['data']['organization_id']}/{res['data']['s3_prefix']}",
-            workspace=self.workspace,
+            workspace=self._workspace,
         )
 
     @typechecked
@@ -99,19 +113,18 @@ class GantryDatasetClient:
 
         return GantryDataset(
             api_client=self._api_client,
-            user_email=self.email,
             dataset_name=res["data"]["name"],
             dataset_id=res["data"]["id"],
             bucket_name=res["data"]["bucket_name"],
             aws_region=res["data"]["aws_region"],
             dataset_s3_prefix=f"{res['data']['organization_id']}/{res['data']['s3_prefix']}",
-            workspace=self.workspace,
+            workspace=self._workspace,
         )
 
     @typechecked
     def list_dataset_versions(self, dataset_name: str) -> List[Dict[str, Any]]:
         """
-        Show dataset commit history
+        List dataset version history
 
         Args:
             name (str): dataset name
