@@ -37,7 +37,9 @@ GANTRY_2_HF_DTYPE = {
     "Boolean": Value(dtype="bool", id=None),
     "Categorical": Value(dtype="string", id=None),
     "UUID": Value(dtype="string", id=None),
+    "ID": Value(dtype="string", id=None),
     "Datetime": Value(dtype="timestamp[ns, tz=UTC]", id=None),
+    "Unix_Time": Value(dtype="int64", id=None),
     "Json": dict(),
     "Image": Value(dtype="string", id=None),
     "Audio": Value(dtype="string", id=None),
@@ -48,6 +50,7 @@ GANTRY_2_HF_DTYPE = {
     "Array<Integer>": Value(dtype="string", id=None),
     "Array<Boolean>": Value(dtype="string", id=None),
     "Array<UUID>": Value(dtype="string", id=None),
+    "Array<ID>": Value(dtype="string", id=None),
     # "Array<String>": Sequence(feature=Value(dtype="string", id=None), length=-1, id=None),
     # "Array<Float>": Sequence(feature=Value(dtype="float64", id=None), length=-1, id=None),
     # "Array<Integer>": Sequence(feature=Value(dtype="int64", id=None), length=-1, id=None),
