@@ -128,7 +128,6 @@ class GantryDataset:
         self,
         api_client: APIClient,
         dataset_name: str,
-        user_email: str,
         dataset_id: uuid.UUID,
         bucket_name: str,
         aws_region: str,
@@ -136,7 +135,6 @@ class GantryDataset:
         workspace: str,
     ):
         self.dataset_name = dataset_name
-        self.user_email = user_email
         self.workspace = workspace
         self._api_client = api_client
         self._dataset_id = dataset_id
@@ -146,10 +144,10 @@ class GantryDataset:
 
     def list_versions(self) -> List[Dict[str, Any]]:
         """
-        Get dataset commits history
+        List dataset version history
 
         Returns:
-            List[Dict[str, Any]]: dataset commits sorted from latest to earliest.
+            List[Dict[str, Any]]: dataset versions from latest to earliest.
         """
         response = self._api_client.request(
             "GET", f"/api/v1/datasets/{self._dataset_id}/commits", raise_for_status=True
@@ -159,7 +157,7 @@ class GantryDataset:
     @_ensure_dataset_exists_locally
     def get_diff(self) -> Dict[str, List[str]]:
         """
-        Get local changes which hasn't been committed
+        Get local changes which hasn't been pushed
         Return:
             {
                 "new_files": List[str],
@@ -180,15 +178,13 @@ class GantryDataset:
     @_ensure_not_deleted
     def push_version(self, message: str) -> Dict[str, Any]:
         """
-        This method will compute the difference between the current commit and the local directory,
-        upload new files and modified files to dataset repo. After that we will update
-        .gantry_artifact.jsonl with the latest dataset info and create a new commit. HEAD file
-        will also be updated using the latest commit information.
+        This method will take a snapshot of the dataset local change and create a new dataset
+        version.
 
         Args:
-            message (str): commit message, can't be empty
+            message (str): version message, can't be empty
         Returns:
-            Commit info
+            Version info
         """
         commit_id = uuid.uuid4()
         diff = self._get_diff_for_commit(commit_id)
@@ -198,7 +194,7 @@ class GantryDataset:
             and not diff[constants.MODIFIED_FILES]
             and not diff[constants.DELETED_FILES]
         ):
-            logger.warning("No local changes to commit!")
+            logger.warning("No local changes to add!")
             return self._get_current_commit()
 
         # Check that HEAD is up to date
@@ -237,7 +233,6 @@ class GantryDataset:
                     "metadata_s3_file_version": version_id,
                     "parent_commit_id": self._get_current_commit()["id"],
                     "commit_id": commit_id,
-                    "email": self.user_email,
                 },
                 raise_for_status=True,
             )
@@ -248,7 +243,7 @@ class GantryDataset:
             self._recover_file(constants.DATASET_MANIFEST_FILE)
             if (
                 e.status_code == 400
-                and 'Details: {"error":"Parent commit out of date!","response":"error"}'
+                and 'Details: {"error":"Parent version out of date!","response":"error"}'
                 in e.args[0]
             ):
                 raise DatasetHeadOutOfDateException
@@ -265,30 +260,31 @@ class GantryDataset:
         self,
         file: IO,
         filename: Optional[str] = None,
-        commit_message: Optional[str] = None,
-        parent_commit_id: Optional[Union[uuid.UUID, str]] = None,
+        message: Optional[str] = None,
+        parent_version_id: Optional[Union[uuid.UUID, str]] = None,
     ) -> Dict[str, Any]:
         """
-        This method will upload a file (such as a file opened with ``open()``) to the dataset in a
-        new commit. Does not rely on the user having the dataset synced, nor does it cause the
-        dataset to sync after the upload.
+        This method will upload a file (such as a file opened with ``open()``) to the dataset and
+        create a new dataset version. Does not rely on the user having the dataset synced,
+        nor does it cause the dataset to sync after the upload.
 
         Args:
             file (IO): the file to be uploaded
             filename (str, Optional): the name of the file to be uploaded. Defaults to the local
                 filename of the file
-            commit_message (str, Optional): the commit message that will be associated with the
+            message (str, Optional): the version message that will be associated with the
                 upload of the file. Defaults to a generic message if not set
+            parent_version_id (uuid.UUID, Optional): If specified, SDK will check whether you are
+                making changes on top of the latest version, if not the operation will fail.
         Returns:
-            Commit info
+            Version info
         """
-        # TODO: require specification of parent commit
         if filename:
             name = filename
         else:
             name = os.path.basename(file.name)
 
-        return self._add_single_file(file, name, commit_message, parent_commit_id)
+        return self._add_single_file(file, name, message, parent_version_id)
 
     @typechecked
     @_ensure_not_deleted
@@ -296,24 +292,25 @@ class GantryDataset:
         self,
         file: IO,
         filename: Optional[str] = None,
-        commit_message: Optional[str] = None,
-        parent_commit_id: Optional[Union[uuid.UUID, str]] = None,
+        message: Optional[str] = None,
+        parent_version_id: Optional[Union[uuid.UUID, str]] = None,
     ) -> Dict[str, Any]:
         """
         This method will upload a csv file (such as a csv file opened with ``open()``) to the
-        tabular_manifests of the dataset in a new commit. Does not rely on the user having the
-        dataset synced, nor does it cause the dataset to sync after the upload.
+        tabular_manifests of the dataset and create a new dataset version. Does not rely on the
+        user having the dataset synced, nor does it cause the dataset to sync after the upload.
 
         Args:
             file (IO): the csv file to be uploaded
             filename (str, Optional): the name of the file to be uploaded. Defaults to the local
                 filename of the file. Name must end with '.csv'
-            commit_message (str, Optional): the commit message that will be associated with the
+            message (str, Optional): the version message that will be associated with the
                 upload of the file. Defaults to a generic message if not set
+            parent_version_id (uuid.UUID, Optional): If specified, SDK will check whether you are
+                making changes on top of the latest version, if not the operation will fail.
         Returns:
-            Commit info
+            Version info
         """
-        # TODO: require specification of parent commit
         if filename:
             name = filename
         else:
@@ -322,7 +319,7 @@ class GantryDataset:
         if name[-4:] != ".csv":
             raise ValueError(f"filename must end with '.csv'! Got filename: {name}")
 
-        return self._add_single_file(file, name, commit_message, parent_commit_id)
+        return self._add_single_file(file, name, message, parent_version_id)
 
     @typechecked
     @_ensure_not_deleted
@@ -330,24 +327,25 @@ class GantryDataset:
         self,
         dataframe: pd.DataFrame,
         csvname: Optional[str] = None,
-        commit_message: Optional[str] = None,
-        parent_commit_id: Optional[Union[uuid.UUID, str]] = None,
+        message: Optional[str] = None,
+        parent_version_id: Optional[Union[uuid.UUID, str]] = None,
     ) -> Dict[str, Any]:
         """
-        This method will upload a pandas DataFrame as a new commit in the form of a csv. Does not
-        rely on the user having the dataset synced, nor does it cause the dataset to sync after the
-        upload.
+        This method will upload a pandas DataFrame in the form of a csv and create a new dataset
+        version. Does not rely on the user having the dataset synced, nor does it cause the dataset
+        to sync after the upload.
 
         Args:
             dataframe (pd.DataFrame): the dataframe to be uploaded
             csvname (str, Optional): the name for the csv that will be uploaded. Defaults to
                 dataframe-[md5 hash].csv
-            commit_message (str, Optional): the commit message that will be associated with the
+            message (str, Optional): the version message that will be associated with the
                 upload of the file. Defaults to a generic message if not set
+            parent_version_id (uuid.UUID, Optional): If specified, SDK will check whether you are
+                making changes on top of the latest version, if not the operation will fail.
         Returns:
-            Commit info
+            Version info
         """
-        # TODO: require specification of parent commit
         if csvname:
             if csvname[-4:] == ".csv":
                 name = csvname
@@ -361,36 +359,33 @@ class GantryDataset:
         dataframe.to_csv(file)
         file.seek(0)
 
-        return self._add_single_file(file, name, commit_message, parent_commit_id)
+        return self._add_single_file(file, name, message, parent_version_id)
 
     @typechecked
     @_ensure_not_deleted
     @_warn_when_local_changes
     def rollback(
-        self, commit_id: Union[str, uuid.UUID], forced: bool = False
+        self, version_id: Union[str, uuid.UUID], forced: bool = False
     ) -> Optional[Dict[str, Any]]:
         """
-        Roll back the dataset to a previous version based on commit id, then pull the newly created
-        commit to the local folder. If there are local changes, will instead do nothing and return
-        None
+        Roll back the dataset to a previous version based on version id, then pull the target
+        version to the local folder.
 
         Args:
-            commit_id (str): target commit id
+            version_id (str): target version id
             forced (bool): whether to ignore the presence of any local changes
         Returns:
-            commit info (optional): commit info if rollback was successsful. None if there were
-                local changes
+            Version info (optional): version info if rollback was successsful.
         """
-        target_commit = self._get_commit(commit_id)
+        target_commit = self._get_commit(version_id)
 
         resp = self._api_client.request(
             "POST",
             f"/api/v1/datasets/{self._dataset_id}/commits",
             json={
-                "message": f"Rollback dataset to commit: {target_commit['id']}",
+                "message": f"Rollback dataset to version: {target_commit['id']}",
                 "metadata_s3_file_version": target_commit["metadata_s3_file_version"],
                 "parent_commit_id": self._get_current_commit()["id"],
-                "email": self.user_email,
             },
             raise_for_status=True,
         )
@@ -404,33 +399,33 @@ class GantryDataset:
     @_ensure_not_deleted
     @_warn_when_local_changes
     def pull(
-        self, commit_id: Optional[Union[str, uuid.UUID]] = None, forced: bool = False
+        self, version_id: Optional[Union[str, uuid.UUID]] = None, forced: bool = False
     ) -> Optional[Dict[str, Any]]:
         """
-        Sync local dataset folder based on a commit id. If commit_id was not provided, will sync
-        based on the latest commit. Will not allow a pull if there are local changes, to avoid
+        Sync local dataset folder based on a version id. If version_id was not provided, will sync
+        based on the latest version. Will not allow a pull if there are local changes, to avoid
         accidentally losing changes
 
         Args:
-            commit_id (str, optional): target commit id. Defaults to None.
+            version_id (str, optional): target version id. Defaults to None.
             forced (bool): whether to ignore the presence of any local changes
         Returns:
-            commit info (optional): commit info if pull was successful. None if there were local
+            version info (optional): version info if pull was successful. None if there were local
                 changes
         """
 
         target_commit = (
-            self._get_commit(commit_id=commit_id) if commit_id else self._get_latest_commit()
+            self._get_commit(commit_id=version_id) if version_id else self._get_latest_commit()
         )
 
-        version_id = target_commit[constants.METADATA_S3_FILE_VERSION]
+        metadata_version_id = target_commit[constants.METADATA_S3_FILE_VERSION]
 
         self._download_files(
             [
                 DatasetFileInfo(
                     file_name=constants.DATASET_MANIFEST_FILE,
                     url=self._get_s3_url(constants.DATASET_MANIFEST_FILE),
-                    version_id=version_id,
+                    version_id=metadata_version_id,
                 )
             ]
         )
@@ -716,7 +711,6 @@ class GantryDataset:
             commit_msg = f"Uploaded {filename} to dataset"
 
         data = {
-            "email": self.user_email,
             "commit_msg": commit_msg,
         }
         files = {
@@ -892,7 +886,7 @@ class GantryDataset:
         training_files = [
             str(p)
             for p in list_all_files(
-                Path(self.workspace) / self.dataset_name / constants.TABULAR_MANIFESTS
+                (Path(self.workspace) / self.dataset_name / constants.TABULAR_MANIFESTS).resolve()
             )
         ]
 
@@ -902,7 +896,6 @@ class GantryDataset:
             dataset_name=self.dataset_name,
             features=self._extract_feature_type(),
         )
-
         hf_loading_script = (
             Path(self.workspace)
             / self.dataset_name
@@ -924,5 +917,5 @@ class GantryDataset:
             # "version_name": commit_info["user_version"],
             "created_at": commit_info["created_at"],
             "created_by": commit_info["created_by"],
-            "is_latest_commit": commit_info["is_latest_commit"],
+            "is_latest_version": commit_info["is_latest_commit"],
         }
