@@ -17,9 +17,8 @@ import pandas as pd
 from typeguard import check_type, typechecked
 
 from gantry.exceptions import GantryBatchCreationException, GantryLoggingException
-from gantry.logger.constants import CHUNK_SIZE, BatchType
+from gantry.logger.constants import CHUNK_SIZE, BatchType, UploadFileType
 from gantry.logger.event_builder import (
-    _build_data_link,
     _build_feedback_event,
     _build_prediction_and_feedback_events,
     _build_prediction_event,
@@ -37,6 +36,7 @@ from gantry.logger.utils import (
     _batch_fail_msg,
     _batch_success_msg,
     _build_batch_iterator,
+    _build_data_link_from_file,
     _check_sample_rate,
     _concurrent_upload_multipart_batch,
     _is_not_empty,
@@ -170,16 +170,25 @@ class Gantry:
         outputs: Optional[List[str]] = None,
         feedbacks: Optional[List[str]] = None,
         tags: Optional[List[str]] = None,
-        feedback_id: Optional[List[str]] = None,
+        feedback_id: Optional[str] = None,
         feedback_keys: Optional[List[str]] = None,
+        sep: str = ",",
+        join_key: Optional[str] = None,
     ) -> None:
         """
-        Ingest a file containing records into Gantry.
+        Ingest a file containing records into Gantry. File MUST contain a header
+        line with column names.
+
         This method provides parameters to customize column name
         mappings to inputs/outputs/feedback/timestamps/etc.
 
         All specifications are specifications of file column names
 
+        IMPORTANT: SDK validation will be done only at the header level
+        (validating inputs/outputs/feedback parametrization is valid).
+        Data itself won't be validated due to potential limitations with
+        file size.
+
         Args:
             application (str): Name of the application to ingest the file into.
             filepath (str): path to the file.
@@ -204,25 +213,32 @@ class Gantry:
             tags (optional, list[str]): by default, all columns that start with 'tags'
                 will be considered feedbacks. Alternatively, you can provide a list of
                 column names using this parameter to be considered tags.
-            feedback_id (optional, list[str]): by default, feedback_id values will be fetched
+            feedback_id (optional, str): by default, feedback_id values will be fetched
                 from a 'feedback_id' named column. Set this parameter to reference
-                different columns.
+                another column.
+                DEPRECATION WARNING: this parameter will be removed soon. Use 'join_key' instead.
             feedback_keys (optional, list[str]): provide a list of column names to be used
                 as feedback_keys.
+                DEPRECATION WARNING: this parameter will be removed soon. Use 'join_key' instead.
+            sep (str, defaults to ','): Character separator, defaults to ',' (for CSV files).
+            join_key (optional, str): by default, feedback_id values will be fetched
+                from a 'join_key' named column. Set this parameter to reference
+                another column.
 
         """
-        data_link = _build_data_link(
-            application,
-            version,
-            timestamp,
-            inputs or [],
-            outputs or [],
-            feedbacks or [],
-            tags or [],
-            feedback_id or [],
-            feedback_keys,
+        data_link = _build_data_link_from_file(
+            application=application,
             filepath=filepath,
-            batch_type=BatchType.RECORD,  # TODO: Determine this by the data_link request.
+            sep=sep,
+            version=str(version) if isinstance(version, int) else version,
+            timestamp=timestamp,
+            inputs=inputs,
+            outputs=outputs,
+            feedback=feedbacks,
+            tags=tags,
+            feedback_id=feedback_id,
+            feedback_keys=feedback_keys,
+            join_key=join_key,
         )
         object_size = os.path.getsize(filepath)  # in bytes
         with open(filepath, "r") as f_in:
@@ -1092,11 +1108,13 @@ class Gantry:
         events: List,
         batch_type: BatchType,
     ) -> str:
-        data_link: DataLink = _build_data_link(
-            application,
-            version=version,
-            events=events,
+        data_link = DataLink(
+            file_type=UploadFileType.EVENTS,
             batch_type=batch_type,
+            num_events=len(events),
+            application=application,
+            version=str(version) if isinstance(version, int) else version,
+            log_timestamp=datetime.datetime.utcnow().isoformat(),
         )
         events_bytesize = sys.getsizeof(json.dumps(events, cls=EventEncoder).encode("utf-8"))
         batch_count = int(
