@@ -163,12 +163,14 @@ def log_file(
     filepath: str,
     version: Optional[Union[int, str]] = None,
     timestamp: Optional[str] = None,
-    inputs: List[str] = [],
-    outputs: List[str] = [],
-    feedbacks: List[str] = [],
-    tags: List[str] = [],
-    feedback_id: List[str] = [],
+    inputs: Optional[List[str]] = None,
+    outputs: Optional[List[str]] = None,
+    feedbacks: Optional[List[str]] = None,
+    tags: Optional[List[str]] = None,
+    feedback_id: Optional[str] = None,
     feedback_keys: Optional[List[str]] = None,
+    sep: str = ",",
+    join_key: Optional[str] = None,
 ):
     return _CLIENT.log_file(**locals())  # type: ignore[union-attr]
 
