@@ -73,16 +73,6 @@ def to_isoformat_duration(relative_interval: datetime.timedelta) -> str:
     return timedelta_str
 
 
-def to_timestamp(dt) -> float:
-    """
-    converts naive Datetime object to a timestamp in seconds.
-
-    implemented for py 2 compatibility:
-    https://stackoverflow.com/questions/8777753/converting-datetime-date-to-utc-timestamp-in-python
-    """
-    return (dt - datetime.datetime(1970, 1, 1)).total_seconds()
-
-
 def _is_offset_naive(d: datetime.datetime) -> bool:
     # https://docs.python.org/3/library/datetime.html#determining-if-an-object-is-aware-or-naive
     aware = d.tzinfo is not None and d.tzinfo.utcoffset(d) is not None
