@@ -1,3 +1,4 @@
+import pathlib
 import uuid
 
 import pytest
@@ -7,14 +8,7 @@ from gantry.api_client import APIClient
 from gantry.dataset.client import GantryDatasetClient
 from gantry.exceptions import DatasetNotFoundError, GantryRequestException
 
-from .conftest import (
-    AWS_REGION,
-    BUCKET_NAME,
-    DATASET_ID,
-    DATASET_NAME,
-    HOST,
-    USER_EMAIL,
-)
+from .conftest import BUCKET_NAME, DATASET_ID, DATASET_NAME, HOST
 
 
 @pytest.fixture
@@ -26,9 +20,6 @@ def test_api_client():
 def test_client(test_api_client):
     return GantryDatasetClient(
         api_client=test_api_client,
-        email=USER_EMAIL,
-        bucket_name=BUCKET_NAME,
-        aws_region=AWS_REGION,
         working_directory=".",
     )
 
@@ -48,7 +39,6 @@ def test_create_dataset(test_client, test_dataset):
             headers={"Content-Type": "application/json"},
         )
         dataset = test_client.create_dataset(DATASET_NAME)
-        assert dataset.user_email == USER_EMAIL
         assert dataset._dataset_id == DATASET_ID
         assert dataset.dataset_name == DATASET_NAME
         assert dataset.workspace == "."
@@ -82,16 +72,15 @@ def test_create_dataset_with_model(test_client, test_dataset):
                 responses.matchers.json_params_matcher(
                     {
                         "name": DATASET_NAME,
-                        "email": USER_EMAIL,
                         "model_id": MODEL_ID,
-                        "aws_region": "us-west-2",
-                        "bucket_name": "test-bucket",
+                        "bucket_name": BUCKET_NAME,
                     }
                 )
             ],
         )
-        dataset = test_client.create_dataset(DATASET_NAME, model_name="test_model")
-        assert dataset.user_email == USER_EMAIL
+        dataset = test_client.create_dataset(
+            DATASET_NAME, bucket_name=BUCKET_NAME, model_name="test_model"
+        )
         assert dataset._dataset_id == DATASET_ID
         assert dataset.dataset_name == DATASET_NAME
         assert dataset.workspace == "."
@@ -112,7 +101,6 @@ def test_get_dataset(test_client, test_dataset):
             headers={"Content-Type": "application/json"},
         )
         dataset = test_client.get_dataset(DATASET_NAME)
-        assert dataset.user_email == USER_EMAIL
         assert dataset._dataset_id == DATASET_ID
         assert dataset.dataset_name == DATASET_NAME
         assert dataset.workspace == "."
@@ -207,3 +195,9 @@ def test_delete_dataset(test_client, test_dataset):
         )
 
         test_client.delete_dataset(DATASET_NAME)
+
+
+def test_set_working_dir(test_client):
+    assert test_client.working_directory == "."
+    test_client.set_working_directory("test_dir")
+    assert test_client.working_directory == str(pathlib.Path("test_dir").resolve())
