@@ -45,7 +45,6 @@ from .conftest import (
     MANIFEST_VERSION_ID,
     README_OBJ_KEY,
     S3_PREFIX,
-    USER_EMAIL,
 )
 
 
@@ -59,7 +58,6 @@ def gantry_dataset_obj(test_api_client, datadir):
     return GantryDataset(
         api_client=test_api_client,
         dataset_name=DATASET_NAME,
-        user_email=USER_EMAIL,
         dataset_id=DATASET_ID,
         bucket_name=BUCKET_NAME,
         aws_region=AWS_REGION,
@@ -273,7 +271,6 @@ def setup_resp_for_create_commit(
                     "metadata_s3_file_version": MANIFEST_VERSION_ID,
                     "parent_commit_id": old_commit["id"],
                     "commit_id": commit_id,
-                    "email": USER_EMAIL,
                 }
             )
         ],
@@ -368,7 +365,6 @@ def setup_resp_for_add_file(resp, commit_message, filename, file):
                     "file": (filename, file),
                 },
                 data={
-                    "email": "test@gantry.dev",
                     "commit_msg": commit_message,
                 },
             )
@@ -593,10 +589,9 @@ def test_rollback(datadir, gantry_dataset_obj, commit_history):
             match=[
                 matchers.json_params_matcher(
                     {
-                        "message": f"Rollback dataset to commit: {original_commit['id']}",
+                        "message": f"Rollback dataset to version: {original_commit['id']}",
                         "metadata_s3_file_version": original_commit["metadata_s3_file_version"],
                         "parent_commit_id": new_commit["id"],
-                        "email": USER_EMAIL,
                     }
                 )
             ],
@@ -952,11 +947,11 @@ def test_add_item_bad_parent(gantry_dataset_obj, function, commit_history):
             )
 
             if function == "push_file":
-                gantry_dataset_obj.push_file(input, parent_commit_id=parent_commit_id)
+                gantry_dataset_obj.push_file(input, parent_version_id=parent_commit_id)
             elif function == "push_tabular_file":
-                gantry_dataset_obj.push_tabular_file(input, parent_commit_id=parent_commit_id)
+                gantry_dataset_obj.push_tabular_file(input, parent_version_id=parent_commit_id)
             elif function == "push_dataframe":
-                gantry_dataset_obj.push_dataframe(input, parent_commit_id=parent_commit_id)
+                gantry_dataset_obj.push_dataframe(input, parent_version_id=parent_commit_id)
 
 
 @pytest.mark.parametrize(("function"), [("push_file"), ("push_tabular_file"), ("push_dataframe")])
@@ -991,13 +986,15 @@ def test_add_item_good_parent(gantry_dataset_obj, function, commit_history, add_
         )
 
         if function == "push_file":
-            new_commit = gantry_dataset_obj.push_file(input, parent_commit_id=parent_commit_id)
+            new_commit = gantry_dataset_obj.push_file(input, parent_version_id=parent_commit_id)
         elif function == "push_tabular_file":
             new_commit = gantry_dataset_obj.push_tabular_file(
-                input, parent_commit_id=parent_commit_id
+                input, parent_version_id=parent_commit_id
             )
         elif function == "push_dataframe":
-            new_commit = gantry_dataset_obj.push_dataframe(input, parent_commit_id=parent_commit_id)
+            new_commit = gantry_dataset_obj.push_dataframe(
+                input, parent_version_id=parent_commit_id
+            )
 
         new_commit["version_id"] == add_file_commit["id"]
         new_commit["dataset"] == gantry_dataset_obj.dataset_name
